Tutorials Overview
==================

At this current point in time there are no tutorials to help you get started.
However, as a way to temporarily fill this gap please post any question you
have to the `PyMedPhys Mailing List`_.

.. _`PyMedPhys Mailing List`: https://groups.google.com/g/pymedphys

If you have an idea for a great PyMedPhys tutorial please discuss this
on the mailing list. If you are new to Python a great resource is the
`NSA Python course`_ written by the creator of Python.

.. _`NSA Python course`: https://ia802805.us.archive.org/7/items/comp3321/comp3321_text.pdf
